@@ -296,51 +296,25 @@ def Item_view_Fetch4(request):
 
 @JsonResponseWithException(printing=False)
 def Item_view_Fetch5(request):
+    from kaf_pas.planing.models.production_ext import Production_ext
     _request = DSRequest(request=request)
 
     data = _request.get_data()
 
     with transaction.atomic():
+        from kaf_pas.planing.models.production_order_opers import Production_order_opersManager
+
         id = data.get('id')
         tmp_table_name = f'production_order_tmp_table'
-        create_tmp_table(
-            on_commit=None,
-            drop=False,
-            sql_str=f'''SELECT t.*
-                        FROM planing_operations po
-                                 join planing_operation_item poi on po.id = poi.operation_id
-                                 join planing_operation_item_add paoi on poi.item_id = paoi.item_id
-                                 CROSS JOIN LATERAL
-                            json_to_recordset(paoi.item_full_name_obj::json) as t(
-                                                                                 "confirmed" text,
-                                                                                 "deliting" boolean,
-                                                                                 "document__file_document" text,
-                                                                                 "document_id" bigint,
-                                                                                 "editing" boolean,
-                                                                                 "id" bigint,
-                                                                                 "isFolder" boolean,
-                                                                                 "lastmodified" text,
-                                                                                 "parent_id" bigint,
-                                                                                 "props" bigint,
-                                                                                 "qty_operations" int4,
-                                                                                 "refs_id" bigint,
-                                                                                 "refs_props" bigint,
-                                                                                 "relevant" text,
-                                                                                 "section" text,
-                                                                                 "STMP_1_id" bigint,
-                                                                                 "STMP_2_id" bigint,
-                                                                                 "version" int4,
-                                                                                 "where_from" text
-                            )
-                        where po.id = %s''',
-            params=[id],
-            table_name=tmp_table_name)
+
+        production_ext = Production_ext()
+        production_ext.get_production_order_tmp_table(tmp_table_name=tmp_table_name, id=id)
 
         return JsonResponse(
             DSResponse(
                 request=request,
                 data=Item_operations_view.objects.raw(
-                    raw_query=f'select * from {tmp_table_name}',
+                    raw_query=f'select  * from {tmp_table_name}',
                     function=Item_operations_viewManager.getRecord
                 ),
                 status=RPCResponseConstant.statusSuccess).response)
