@@ -3,6 +3,7 @@ import logging
 from bitfield import BitField
 from django.conf import settings
 from django.db import transaction
+
 from isc_common.bit import TurnBitOn
 from isc_common.common import blinkString
 from isc_common.common.mat_views import refresh_mat_view
@@ -10,10 +11,8 @@ from isc_common.datetime import DateTimeToStr
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
 from isc_common.number import DelProps
-from isc_common.progress import managed_progress, ProgressDroped
-
+from isc_common.progress import managed_progress, ProgressDroped, progress_deleted
 from kaf_pas.kd.models.pathes import Pathes
-from kaf_pas.production.models import progress_deleted
 
 logger = logging.getLogger(__name__)
 
@@ -53,7 +52,6 @@ class UploadesManager(AuditManager):
 
     @staticmethod
     def del_upload(id, user, doc_cnt=0, lotsman_cnt=0, document_id=None, last_step=False):
-        from isc_common.models.deleted_progresses import Deleted_progresses
         from kaf_pas.ckk.models.item import Item
         from kaf_pas.ckk.models.item import ItemManager
         from kaf_pas.ckk.models.item_document import Item_document
@@ -69,11 +67,16 @@ class UploadesManager(AuditManager):
         from kaf_pas.kd.models.lotsman_documents_hierarcy_refs import Lotsman_documents_hierarcy_refs
         from kaf_pas.kd.models.uploades_documents import Uploades_documents
         from kaf_pas.kd.models.uploades_log import Uploades_log
+        from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
+        from kaf_pas.common.events_manager import EventStack
 
-        if settings.LOCKS.locked(f'UploadesManager.del_upload_{id}'):
+        # eventStack = EventStack()
+
+        key = f'UploadesManager.del_upload_{id}'
+        if settings.LOCKS.locked(key):
             return
 
-        settings.LOCKS.acquire(f'UploadesManager.del_upload_{id}')
+        settings.LOCKS.acquire(key)
 
         if document_id == None:
             for upload_document in Uploades_documents.objects.filter(upload_id=id):
@@ -97,6 +100,7 @@ class UploadesManager(AuditManager):
         ) as progress:
             try:
                 res = 0
+                Tmp_Item_refsManager.create()
                 with transaction.atomic():
                     continue_cnt = 0
 
@@ -196,6 +200,7 @@ class UploadesManager(AuditManager):
                         # logger.debug(f'deleted: {deleted}')
                         if document_id == None:
                             res += Uploades.objects.filter(id=id).delete()[0]
+                            # eventStack.EVENTS_DOWNLOAD_CONFIRM.send_message(message=progress.progresses.label_contents)
 
                 if doc_cnt > 0 and last_step:
                     progress.setContentsLabel(blinkString(text='Обновление представления "kd_documents_mview"', color='blue'))
@@ -205,15 +210,11 @@ class UploadesManager(AuditManager):
                     progress.setContentsLabel(blinkString(text='Обновление представления "kd_lotsman_documents_hierarcy_mview"', color='blue'))
                     refresh_mat_view('kd_lotsman_documents_hierarcy_mview')
 
-                settings.LOCKS.release(f'UploadesManager.del_upload_{id}')
+                settings.LOCKS.release(key)
                 return res, doc_cnt, lotsman_cnt
-            except ProgressDroped as ex:
-                Deleted_progresses.objects.filter(id_progress=progress.id, user=progress.user).delete()
-                settings.LOCKS.release(f'UploadesManager.del_upload_{id}')
-                raise ex
 
             except Exception as ex:
-                settings.LOCKS.release(f'UploadesManager.del_upload_{id}')
+                settings.LOCKS.release(key)
                 raise ex
 
     def deleteFromRequest(self, request):
@@ -257,6 +258,7 @@ class UploadesManager(AuditManager):
 
     def change_confirm(self, data, user, kind='confirm'):
         from kaf_pas.ckk.models.item import Item
+        from kaf_pas.ckk.models.item import ItemManager
         from kaf_pas.kd.models.lotsman_documents_hierarcy import Lotsman_documents_hierarcy
         from kaf_pas.kd.models.uploades_documents import Uploades_documents
 
@@ -270,74 +272,58 @@ class UploadesManager(AuditManager):
                     message='Подсчет товарных позиций',
                     props=TurnBitOn(0, 0)
             ) as progress:
-                try:
-                    with transaction.atomic():
-                        for upload in Uploades.objects.select_for_update().filter(id__in=data.get('ids')):
-                            for uploades_document in Uploades_documents.objects.filter(upload=upload):
-                                res += Item.objects.filter(document=uploades_document.document).count()
+                with transaction.atomic():
+                    for upload in Uploades.objects.select_for_update().filter(id__in=data.get('ids')):
+                        for uploades_document in Uploades_documents.objects.filter(upload=upload):
+                            res += Item.objects.filter(document=uploades_document.document).count()
 
-                                for lotsman_documents_hierarcy in Lotsman_documents_hierarcy.objects.filter(document=uploades_document.document):
-                                    res += Item.objects.filter(lotsman_document=lotsman_documents_hierarcy).count()
+                            for lotsman_documents_hierarcy in Lotsman_documents_hierarcy.objects.filter(document=uploades_document.document):
+                                res += Item.objects.filter(lotsman_document=lotsman_documents_hierarcy).count()
 
-                            if res == 0:
-                                raise Exception(f'Товарных позиций не найдено.')
+                        if res == 0:
+                            raise Exception(f'Товарных позиций не найдено.')
 
-                            progress.setQty(qty=res)
-                            if kind == 'confirm':
-                                progress.setContentsLabel(content=blinkString(f'Подтверждение закачки {upload.path.drived_absolute_path} от {DateTimeToStr(upload.lastmodified, hours=3)}', blink=False, bold=True))
-                            else:
-                                progress.setContentsLabel(content=blinkString(f'Отмена Подтверждения закачки {upload.path.drived_absolute_path} от {DateTimeToStr(upload.lastmodified, hours=3)}', blink=False, bold=True))
-                            for uploades_document in Uploades_documents.objects.filter(upload=upload):
-                                for item in Item.objects.filter(document=uploades_document.document):
+                        progress.setQty(qty=res)
+                        if kind == 'confirm':
+                            progress.setContentsLabel(content=blinkString(f'Подтверждение закачки {upload.path.drived_absolute_path} от {DateTimeToStr(upload.lastmodified, hours=3)}', blink=False, bold=True))
+                        else:
+                            progress.setContentsLabel(content=blinkString(f'Отмена Подтверждения закачки {upload.path.drived_absolute_path} от {DateTimeToStr(upload.lastmodified, hours=3)}', blink=False, bold=True))
+
+                        for uploades_document in Uploades_documents.objects.filter(upload=upload):
+                            for item in Item.objects.filter(document=uploades_document.document):
+                                if kind == 'confirm':
+                                    item.props |= Item.props.confirmed
+                                else:
+                                    item.props &= ~Item.props.confirmed
+
+                                item.version == ItemManager.get_verstion(
+                                    STMP_1=item.STMP_1,
+                                    STMP_2=item.STMP_2,
+                                    props=item.props
+                                )
+                                item.save()
+                                if progress.step() != 0:
+                                    raise ProgressDroped
+                                logger.debug(f'progress.step() = {progress.cnt}')
+
+                            for lotsman_documents_hierarcy in Lotsman_documents_hierarcy.objects.filter(document=uploades_document.document):
+                                for item in Item.objects.filter(lotsman_document=lotsman_documents_hierarcy):
                                     if kind == 'confirm':
                                         item.props |= Item.props.confirmed
                                     else:
                                         item.props &= ~Item.props.confirmed
-                                    while True:
-                                        try:
-                                            Item.objects.get(
-                                                STMP_1=item.STMP_1,
-                                                STMP_2=item.STMP_2,
-                                                props=item.props,
-                                                version=item.version
-                                            )
-                                            if item.version == None:
-                                                item.version = 1
-                                            else:
-                                                item.version += 1
-                                        except Item.DoesNotExist:
-                                            break
-                                        except Item.MultipleObjectsReturned:
-                                            if item.version == None:
-                                                item.version = 1
-                                            else:
-                                                item.version += 1
                                     item.save()
                                     if progress.step() != 0:
                                         raise ProgressDroped
-                                    logger.debug(f'progress.step() = {progress.cnt}')
+                                    logger.debug(f'lotsman progress.step() = {progress.cnt}')
 
-                                for lotsman_documents_hierarcy in Lotsman_documents_hierarcy.objects.filter(document=uploades_document.document):
-                                    for item in Item.objects.filter(lotsman_document=lotsman_documents_hierarcy):
-                                        if kind == 'confirm':
-                                            item.props |= Item.props.confirmed
-                                        else:
-                                            item.props &= ~Item.props.confirmed
-                                        item.save()
-                                        if progress.step() != 0:
-                                            raise ProgressDroped
-                                        logger.debug(f'lotsman progress.step() = {progress.cnt}')
-
-                            if kind == 'confirm':
-                                upload.props |= Uploades.props.confirmed
-                            else:
-                                upload.props &= ~Uploades.props.confirmed
-                            upload.save()
-                        progress.sendMessage(type='refresh_uploads_grid')
-                except ProgressDroped as ex:
-                    from isc_common.models.deleted_progresses import Deleted_progresses
-                    Deleted_progresses.objects.filter(id_progress=progress.id, user=progress.user).delete()
-                    raise ex
+                        if kind == 'confirm':
+                            upload.props |= Uploades.props.confirmed
+                        else:
+                            upload.props &= ~Uploades.props.confirmed
+                        upload.save()
+                        settings.EVENT_STACK.EVENTS_DOWNLOAD_CONFIRM.send_message(message=progress.progresses.label_contents)
+                    progress.sendMessage(type='refresh_uploads_grid')
 
         return res
 
