@@ -1,8 +1,5 @@
 import logging
 
-from django.contrib.postgres.fields import JSONField
-from django.db.models import TextField
-
 from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
 from kaf_pas.ckk.models.item import Item
@@ -33,13 +30,11 @@ class Operation_itemManager(AuditManager):
 class Operation_item(AuditModel):
     operation = ForeignKeyCascade(Operations)
     item = ForeignKeyProtect(Item)
-    item_full_name = TextField()
-    item_full_name_obj = JSONField(default=dict)
 
     objects = Operation_itemManager()
 
     def __str__(self):
-        return f"ID:{self.id}, operation: [{self.operation}], item: [{self.item}], item_full_name: {self.item_full_name}, item_full_name_obj: {self.item_full_name_obj}"
+        return f"ID:{self.id}, operation: [{self.operation}], item: [{self.item}]"
 
     def __repr__(self):
         return self.__str__()
