@@ -17,6 +17,9 @@ class Operation_refsQuerySet(TreeAuditModelQuerySet):
 
         return super().delete()
 
+    # def get(self, *args, **kwargs):
+    #     return super().get(*args, **kwargs)
+
 
 class Operation_refsManager(TreeAuditModelManager):
 
@@ -27,7 +30,7 @@ class Operation_refsManager(TreeAuditModelManager):
             ('outer_routing', 'Связь операций между товарными позициями'),  # 1-2
             ('product_order_routing', 'Связи в блоке задания на производство'),  # 2-4
             ('product_making', 'Связи выпуска'),  # 3-8
-            ('product_making_block', 'Блок операций выпуска, удаляется как одно целоеб для правильного удаления релизов'),  # 3-8
+            ('product_making_block', 'Блок операций выпуска, удаляется как одно целое для правильного удаления релизов'),  # 4-16
         ), default=0, db_index=True)
 
     @staticmethod
@@ -46,14 +49,16 @@ class Operation_refsManager(TreeAuditModelManager):
 
 class Operation_refs(AuditModel):
     parent = ForeignKeyProtect(Operations, related_name='operation_parent', blank=True, null=True)
-    parent_real = ForeignKeyProtect(Operations, related_name='operation_parent_real', blank=True, null=True)
     child = ForeignKeyProtect(Operations, related_name='operation_child')
     props = Operation_refsManager.props()
 
     objects = Operation_refsManager()
 
     def __str__(self):
-        return f"ID:{self.id},\n child: [{self.child}],\n parent: [{self.parent}]"
+        return f"ID:{self.id},\n " \
+               f"props: [{self.props}],\n " \
+               f"child: [{self.child}],\n " \
+               f"parent: [{self.parent}]"
 
     def __repr__(self):
         return self.__str__()
@@ -62,8 +67,9 @@ class Operation_refs(AuditModel):
         verbose_name = 'Кросс таблица операций планирования'
         constraints = [
             CheckConstraint(check=~Q(child=F('parent')), name='Operation_refs_not_circulate_refs'),
-            UniqueConstraint(fields=['child'], condition=Q(parent=None) & Q(parent_real=None), name='Operation_refs_unique_constraint_0'),
-            UniqueConstraint(fields=['child', 'parent'], condition=Q(parent_real=None), name='Operation_refs_unique_constraint_1'),
-            UniqueConstraint(fields=['child', 'parent_real'], condition=Q(parent=None), name='Operation_refs_unique_constraint_2'),
-            UniqueConstraint(fields=['child', 'parent', 'parent_real'], name='Operation_refs_unique_constraint_3'),
+            UniqueConstraint(fields=['child', 'props'], condition=Q(deleted_at=None) & Q(parent=None), name='Operation_refs_unique_constraint_0'),
+            UniqueConstraint(fields=['child', 'parent', 'props'], condition=Q(deleted_at=None), name='Operation_refs_unique_constraint_1'),
+            UniqueConstraint(fields=['child', 'deleted_at', 'props'], condition=Q(parent=None), name='Operation_refs_unique_constraint_2'),
+            UniqueConstraint(fields=['child', 'deleted_at', 'parent', 'props'], name='Operation_refs_unique_constraint_3'),
+
         ]
