@@ -4,11 +4,11 @@ from datetime import datetime
 
 from django.conf import settings
 from django.contrib.postgres.fields import ArrayField
-from django.db import transaction
+from django.db import transaction, connection
 from django.db.models import DecimalField, DateTimeField, TextField, BooleanField, BigIntegerField, PositiveIntegerField
 from django.forms import model_to_dict
 
-from isc_common import setAttr, delAttr, NotImplementation
+from isc_common import setAttr, delAttr, NotImplement
 from isc_common.auth.models.user import User
 from isc_common.common import blinkString, red, restarted, new
 from isc_common.common.functions import ExecuteStoredProc
@@ -16,6 +16,7 @@ from isc_common.datetime import DateTimeToStr
 from isc_common.fields.code_field import CodeField
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.http.DSRequest import DSRequest
+from isc_common.managers.common_manager import CommonManager
 from isc_common.models.base_ref import Hierarcy
 from isc_common.number import DecimalToStr, ToDecimal
 from kaf_pas.ckk.models.ed_izm import Ed_izm
@@ -24,7 +25,9 @@ from kaf_pas.ckk.models.locations import Locations
 from kaf_pas.planing.models.operation_item_view import Operation_item_view
 from kaf_pas.planing.models.operation_launches import Operation_launches
 from kaf_pas.planing.models.operation_types import Operation_types
-from kaf_pas.planing.models.operations import OperationsManager, OperationsQuerySet
+from kaf_pas.planing.models.operations import OperationsManager, OperationsQuerySet, Operations
+from kaf_pas.planing.models.production_ext import Production_ext
+from kaf_pas.planing.models.rouning_ext import Routing_ext
 from kaf_pas.production.models.launches import Launches
 
 logger = logging.getLogger(__name__)
@@ -32,6 +35,34 @@ logger = logging.getLogger(__name__)
 
 class Production_orderQuerySet(OperationsQuerySet):
 
+    def get_range_rows1(self, request, function=None, distinct_field_names=None, remove_fields=None):
+        request = DSRequest(request=request)
+        data = request.get_data()
+
+        _data = data
+        delAttr(_data, 'arranged')
+
+        if data.get('location_id'):
+            _data = setAttr(_data, 'location_id', data.get('location_id'))
+
+        if data.get('launch_id'):
+            _data = setAttr(_data, 'launch_id', data.get('launch_id'))
+
+        request.set_data(_data)
+
+        self.alive_only = request.alive_only
+        self.enabledAll = request.enabledAll
+        res = self.get_range_rows(
+            start=request.startRow,
+            end=request.endRow,
+            function=function,
+            distinct_field_names=distinct_field_names,
+            json=request.json,
+            criteria=request.get_criteria(),
+            user=request.user
+        )
+        return res
+
     def get_info(self, request, *args):
         request = DSRequest(request=request)
         data = request.get_data()
@@ -51,99 +82,31 @@ class Production_orderQuerySet(OperationsQuerySet):
 
                 json_all = copy.deepcopy(request.json)
                 delAttr(json_all.get('data'), 'location_id')
+                delAttr(json_all.get('data'), 'arranged')
 
+        data = request.get_data()
+        data = {k: v for k, v in request.get_data().items() if v is not None and k != 'arranged'}
+
+        request.set_data(data)
         criteria = self.get_criteria(json=request.json)
         criteria_all = self.get_criteria(json=json_all)
         if executor != None:
-            cnt = super().filter(exucutors__overlap=[executor.id]).filter(*args, criteria).count()
-            cnt_all = super().filter(exucutors__overlap=[executor.id]).filter(*args, criteria_all).count()
+            if data.get('arranged'):
+                cnt = super().filter(arranges_exucutors__overlap=[executor.id]).filter(*args, criteria).count()
+                cnt_all = super().filter(arranges_exucutors__overlap=[executor.id]).filter(*args, criteria_all).count()
+            else:
+                cnt = super().filter(exucutors__overlap=[executor.id]).filter(*args, criteria).count()
+                cnt_all = super().filter(exucutors__overlap=[executor.id]).filter(*args, criteria_all).count()
         else:
-            cnt = super().filter(*args, criteria).count()
-            cnt_all = super().filter(*args, criteria_all).count()
+            if data.get('arranged'):
+                cnt = super().filter(arranges_exucutors__overlap=[executor.id]).filter(*args, criteria).count()
+                cnt_all = super().filter(arranges_exucutors__overlap=[executor.id]).filter(*args, criteria_all).count()
+            else:
+                cnt = super().filter(*args, criteria).count()
+                cnt_all = super().filter(*args, criteria_all).count()
 
         return dict(qty_rows=cnt, all_rows=cnt_all)
 
-    @staticmethod
-    def start(qty, _data, user, lock=True):
-        from kaf_pas.planing.models.operation_refs import Operation_refs
-        from kaf_pas.planing.models.operation_value import Operation_value
-        from kaf_pas.planing.models.operations import Operations
-        _res = []
-        key = f'''get_setStartStatus_{_data.get('id')}'''
-        if lock:
-            settings.LOCKS.acquire(key)
-        try:
-            value_made = ExecuteStoredProc('get_value_made', [_data.get('id'), _data.get('launch_id')])
-
-            if value_made > qty:
-                if lock:
-                    settings.LOCKS.release(key)
-                raise Exception('Количество выпуска больше введенной суммы.')
-
-            parent = Operations.objects.get(id=_data.get('id'))
-
-            operation_refs = Operation_refs.objects.filter(
-                parent=parent,
-                child__opertype__code='LAUNCH_TSK'
-            )
-
-            if operation_refs.count() > 0:
-                if qty == 0:
-                    Operation_value.objects.filter(operation=operation_refs[0].child).delete()
-                    Operation_launches.objects.filter(operation=operation_refs[0].child).delete()
-                    parent.status = settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(new)
-                    operation_refs.delete()
-
-                else:
-                    Operation_value.objects.update_or_create(operation=operation_refs[0].child, defaults=dict(value=qty))
-                    Operation_launches.objects.get_or_create(operation=operation_refs[0].child, launch=operation_refs[0].child.launch)
-                    parent.status = settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(restarted)
-
-                parent.creator = user
-                parent.save()
-
-                if qty != 0:
-                    res = model_to_dict(operation_refs[0].parent)
-                    _data.update(res)
-                    _res.append(_data)
-
-                setAttr(_data, 'value_start', qty)
-
-            else:
-                if qty == 0:
-                    if lock:
-                        settings.LOCKS.release(key)
-                    return _res
-
-                res = Operations.objects.create(
-                    opertype=settings.OPERS_TYPES_STACK.LAUNCH_TASK,
-                    date=datetime.now(),
-                    status=settings.OPERS_TYPES_STACK.LAUNCH_TASK_STATUSES.get('new'),
-                    creator=user
-                )
-
-                parent = Operations.objects.get(id=_data.get('id'))
-                parent.status = settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get('started')
-                parent.creator = user
-                parent.save()
-
-                Operation_refs.objects.create(parent=parent, child=res)
-                Operation_value.objects.create(operation=res, edizm_id=_data.get('edizm_id'), value=qty)
-                Operation_launches.objects.get_or_create(operation=res, launch_id=_data.get('launch_id'))
-
-                res = model_to_dict(res)
-                _data.update(res)
-                setAttr(_data, 'value_start', qty)
-                _res.append(_data)
-
-            if lock:
-                settings.LOCKS.release(key)
-            return _res
-        except Exception as ex:
-            if lock:
-                settings.LOCKS.release(key)
-            raise ex
-
     def get_setStartStatus(self, request):
 
         request = DSRequest(request=request)
@@ -163,8 +126,10 @@ class Production_orderQuerySet(OperationsQuerySet):
                     break
                 idx += 1
 
-                _res = Production_orderQuerySet.start(
-                    _data=_data,
+                production_ext = Production_ext()
+
+                _res = production_ext.start(
+                    _data=self.delete_underscore_element(_data),
                     qty=qty,
                     user=request.user
                 )
@@ -197,7 +162,34 @@ class Production_orderQuerySet(OperationsQuerySet):
         return [UserManager.getRecord1(User.objects.get(id=id)) for id in res2]
 
 
-class Production_orderManager(OperationsManager):
+class Production_orderManager(CommonManager):
+    production_ext = Production_ext()
+    routing_ext = Routing_ext()
+
+    def updateFromRequest4(self, request):
+
+        if not isinstance(request, DSRequest):
+            request = DSRequest(request=request)
+
+        data = request.get_data()
+        executors = data.get('executors')
+
+        idx = 0
+        with transaction.atomic():
+            while True:
+                _data = data.get(str(idx))
+                if _data == None:
+                    break
+                idx += 1
+
+                operation_id = _data.get('id')
+                description = _data.get('description')
+
+                Operations.objects.update_or_create(id=operation_id, defaults=dict(description=description))
+                self.production_ext.set_executors(executors=executors, operation_id=operation_id, user=request.user)
+
+        return data
+
     def createFromRequest(self, request):
         from kaf_pas.planing.models.launch_items import Launch_itemsManager
         from kaf_pas.production.models.launch_item_view import Launch_item_viewManager
@@ -235,7 +227,7 @@ class Production_orderManager(OperationsManager):
             if len(launch_items) == 0:
                 raise Exception(blinkString(text=f'''{item.item_name} не включена ни в одну производственную спецификвцию данного запуска.''', blink=False, color=red, bold=True))
 
-            raise NotImplementation()
+            raise NotImplement()
 
             # route_oparation_item = dict(
             #     item_id=item_id,
@@ -288,28 +280,6 @@ class Production_orderManager(OperationsManager):
             # res = model_to_dict(production_order_operation)
         return data
 
-    @staticmethod
-    def get_resource_workshop(location_id):
-        from kaf_pas.ckk.models.locations import Locations
-
-        res = None
-        for location in Locations.objects_tree.get_parents(id=location_id, child_id='id', include_self=False):
-            if location.props.isWorkshop == True:
-                res = dict(id=location.id, title=location.name, prompt=location.full_name)
-                break
-
-        if res == None:
-            raise Exception(f'Не обнаружен цех, с признаком "Уровень цеха" для : {Locations.objects.get(id=location_id).full_name}')
-        return res
-
-    @staticmethod
-    def getRecordLocations(record):
-        return Production_orderManager.get_resource_workshop(record.get('location_id'))
-
-    @staticmethod
-    def getRecordLevels(record):
-        return dict(id=record.get('level_id'), title=record.get('level__name'))
-
     def get_queryset(self):
         return Production_orderQuerySet(self.model, using=self._db)
 
@@ -341,7 +311,8 @@ class Production_orderManager(OperationsManager):
             'isFolder': record.isFolder,
             'cnt_opers': record.cnt_opers,
             'value_sum': DecimalToStr(record.value_sum),
-            'value1_sum': DecimalToStr(record.value1_sum),
+            'value1_sum': ' / '.join([DecimalToStr(v) for v in record.value1_sum]),
+            'value1_sum_len': len(record.value1_sum),
             'value_made': DecimalToStr(record.value_made),
             'value_made_str': f'''{blinkString(DecimalToStr(record.value_made), blink=True if percents >= 100 else False, color="blue", bold=True)}({percents_str}%)''',
             'value_start': DecimalToStr(record.value_start),
@@ -355,6 +326,45 @@ class Production_orderManager(OperationsManager):
         }
         return res
 
+    @staticmethod
+    def getRecordLocations(record):
+        return Production_orderManager.get_resource_workshop(record.get('location_id'))
+
+    @staticmethod
+    def getRecordLevels(record):
+        return dict(id=record.get('level_id'), title=record.get('level__name'))
+
+    @staticmethod
+    def get_resource_workshop(location_id):
+        from kaf_pas.ckk.models.locations import Locations
+
+        res = None
+        for location in Locations.objects_tree.get_parents(id=location_id, child_id='id', include_self=False):
+            if location.props.isWorkshop == True:
+                res = dict(id=location.id, title=location.name, prompt=location.full_name)
+                break
+
+        if res == None:
+            raise Exception(f'Не обнаружен цех, с признаком "Уровень цеха" для : {Locations.objects.get(id=location_id).full_name}')
+        return res
+
+    def makeProdOrderFromRequest(self, request):
+        request = DSRequest(request=request)
+        data = request.get_data()
+        _data = data.copy()
+        setAttr(_data, 'user', request.user)
+        self.routing_ext.make_routing(data=_data)
+        self.production_ext.make_production_order(data=_data)
+        return data
+
+    def deleteProdOrderFromRequest(self, request):
+        request = DSRequest(request=request)
+        data = request.get_data()
+        _data = data.copy()
+        setAttr(_data, 'user', request.user)
+        self.production_ext.delete_production_order(data=_data)
+        return data
+
 
 class Production_order(Hierarcy):
     from kaf_pas.planing.models.status_operation_types import Status_operation_types
@@ -369,6 +379,7 @@ class Production_order(Hierarcy):
     opertype = ForeignKeyProtect(Operation_types, related_name='Production_order_opertype')
     creator = ForeignKeyProtect(User, related_name='Production_order_creator')
     exucutors = ArrayField(BigIntegerField(), default=list)
+    arranges_exucutors = ArrayField(BigIntegerField(), default=list)
     status = ForeignKeyProtect(Status_operation_types)
     launch = ForeignKeyProtect(Launches)
     location = ForeignKeyProtect(Locations)
@@ -381,7 +392,7 @@ class Production_order(Hierarcy):
     cnt_opers = PositiveIntegerField()
 
     value_sum = DecimalField(decimal_places=4, max_digits=19)
-    value1_sum = DecimalField(decimal_places=4, max_digits=19)
+    value1_sum = ArrayField(DecimalField(decimal_places=4, max_digits=19))
     value_start = DecimalField(decimal_places=4, max_digits=19, null=True, blank=True)
     value_made = DecimalField(decimal_places=4, max_digits=19, null=True, blank=True)
     value_odd = DecimalField(decimal_places=4, max_digits=19)
