@@ -104,3 +104,12 @@ def Routing_FetchLocationsLevel(request):
 @JsonResponseWithException()
 def Routing_FetchResourcesLevel(request):
     return JsonResponse(DSResponse(request=request, data=Routing.objects.fetchResourcesLevelFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
+
+@JsonResponseWithException()
+def Routing_CleanRoutes(request):
+    return JsonResponse(DSResponseUpdate(data=Routing.objects.cleanRoutesFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
+
+
+@JsonResponseWithException()
+def Routing_ReCalcRoutes(request):
+    return JsonResponse(DSResponseUpdate(data=Routing.objects.reCalcRoutesFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
