@@ -7,7 +7,7 @@ from django.forms import model_to_dict
 
 from isc_common import setAttr, delAttr
 from isc_common.bit import IsBitOn
-from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade, ForeignKeySetNull
+from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
 from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
 from isc_common.models.audit import AuditModel
@@ -97,7 +97,7 @@ class Launch_operations_materialManager(CommonManagetWithLookUpFieldsManager):
             'edizm_id': record.edizm.id,
             'edizm__code': record.edizm.code,
             'edizm__name': record.edizm.name,
-            'qty':  DecimalToStr(record.qty),
+            'qty': DecimalToStr(record.qty),
             'props': record.props._value,
             'enabled': IsBitOn(record.props, 0),
             'editing': record.editing,
@@ -114,8 +114,8 @@ class Launch_operations_material(AuditModel):
     launch_operationitem = ForeignKeyCascade(Launch_operations_item)
     material = ForeignKeyProtect(Materials, null=True, blank=True)
     material_askon = ForeignKeyProtect(Material_askon, null=True, blank=True)
-    operation_material = ForeignKeySetNull(Operation_material, null=True, blank=True)
-    qty = DecimalField(max_digits=10, decimal_places=4, default=0.0)
+    operation_material = ForeignKeyProtect(Operation_material, null=True, blank=True)
+    qty = DecimalField(max_digits=10, decimal_places=4, default=0)
 
     props = BitField(flags=(
         ('enabled', 'Доступность в данной производственной спецификации'),  # 1
@@ -147,7 +147,12 @@ class Launch_operations_material(AuditModel):
     objects = Launch_operations_materialManager()
 
     def __str__(self):
-        return f"{self.complex_name}"
+        return f"ID: {self.id}, \n" \
+               f"qty: {self.qty}, \n" \
+               f"launch_operationitem: [{self.launch_operationitem}], \n" \
+               f"material: [{self.material}], \n" \
+               f"material_askon: [{self.material_askon}], \n" \
+               f"operation_material: [{self.operation_material}], \n" \
 
     class Meta:
         verbose_name = 'Кросс таблица'
