@@ -34,9 +34,6 @@ class Operation_materialQuerySet(CommonManagetWithLookUpFieldsQuerySet):
         setAttr(kwargs, '_operation', 'create')
         return super().create(**kwargs)
 
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
-
 
 class Operation_materialManager(CommonManagetWithLookUpFieldsManager):
 
@@ -122,7 +119,7 @@ class Operation_material(Hierarcy):
     objects = Operation_materialManager()
 
     def __str__(self):
-        return f"{self.id}"
+        return f"ID: {self.id}, material: [{self.material}], material_askon: [{self.material_askon}], edizm: [{self.edizm}], qty: {self.qty}"
 
     class Meta:
         verbose_name = 'Кросс таблица'
