@@ -1,5 +1,6 @@
 import logging
 
+from bitfield import BitField
 from django.conf import settings
 from django.db import transaction, connection
 from django.db.models import PositiveIntegerField
@@ -19,12 +20,26 @@ logger = logging.getLogger(__name__)
 
 
 class Operations_itemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    def create(self, **kwargs):
+        if kwargs.get('props') == None:
+            setAttr(kwargs, 'props', Operations_item.props.created)
+        return super().create(**kwargs)
+
+    def update(self, **kwargs):
+        if kwargs.get('props') == None:
+            setAttr(kwargs, 'props', Operations_item.props.updated)
+        return super().update(**kwargs)
 
 
 class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
 
+    @staticmethod
+    def props():
+        return BitField(flags=(
+            ('created', 'Операция добавлена'),  # 1
+            ('updated', 'Операция изменена'),  # 2
+        ), default=0, db_index=True)
+
     @staticmethod
     def refresh_num1():
         key='Operations_itemManager.refresh_num1'
@@ -199,16 +214,29 @@ class Operations_itemManager(CommonManagetWithLookUpFieldsManager):
 
 class Operations_item(Hierarcy):
     description = DescriptionField()
-    ed_izm = ForeignKeyProtect(Ed_izm, default=None, null=True, blank=True)
     item = ForeignKeyProtect(Item)
     num = PositiveIntegerField(default=None, null=True, blank=True)
+    old_num = PositiveIntegerField(db_index=True, null=True, blank=True)
     operation = ForeignKeyProtect(Operations)
+    props = Operations_itemManager.props()
+    ed_izm = ForeignKeyProtect(Ed_izm, default=None, null=True, blank=True)
     qty = PositiveIntegerField(default=None, null=True, blank=True)
 
     objects = Operations_itemManager()
 
     def __str__(self):
-        return f"ID:{self.id}, item: [{self.item}], id_izm: [{self.ed_izm}], qty: {self.qty}, num: {self.num}"
+        # return f"ID:{self.id}, \n" \
+        #        f"item: [{self.item}], \n" \
+        #        f"id_izm: [{self.ed_izm}], \n" \
+        #        f"operation: [{self.operation}], \n" \
+        #        f"props: {self.props}, \n" \
+        #        f"qty: {self.qty}, \n" \
+        #        f"old_num: {self.old_num}, \n" \
+        #        f"num: {self.num}"
+
+        return f"operation ID:{self.operation.id}, " \
+               f"num: {self.num}, " \
+               f"old_num: {self.old_num}"
 
     class Meta:
         verbose_name = 'Кросс таблица'
