@@ -2,6 +2,7 @@ import logging
 
 from django.db.models import BooleanField
 
+from isc_common.fields.name_field import NameField
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
 from isc_common.models.base_ref import BaseRefHierarcy
 from isc_common.number import DelProps
@@ -26,6 +27,7 @@ class Operations_viewManager(CommonManagetWithLookUpFieldsManager):
             "id": record.id,
             "lastmodified": record.lastmodified,
             "name": record.name,
+            "direction": record.direction,
             "parent_id": record.parent_id,
             'assemly': record.props.assemly,
             'deliting': record.deliting,
@@ -44,6 +46,7 @@ class Operations_viewManager(CommonManagetWithLookUpFieldsManager):
 class Operations_view(BaseRefHierarcy):
     isFolder = BooleanField()
     props = OperationsManager.get_props()
+    direction = NameField()
 
     objects = Operations_viewManager()
 
